@@ -2,7 +2,7 @@
 # Copyright (c) 2006-2010 Phil Christensen
 # http://modu.bubblehouse.org
 #
-# $Id: blog.py 1231 2010-02-04 05:27:06Z phil $
+# $Id: blog.py 1258 2010-02-06 02:28:35Z phil $
 #
 
 from modu.web import resource, app
@@ -17,16 +17,19 @@ class Resource(resource.CheetahTemplateResource):
 		if not(req.postpath):
 			app.redirect(req.get_path('/'))
 		
+		req.store.ensure_factory('blog', blog.Blog)
+		
 		try:
 			blog_id = int(req.postpath[0])
 		except ValueError:
-			app.redirect(req.get_path('/'))
-		
-		req.store.ensure_factory('blog', blog.Blog, force=True)
-		b = req.store.load_one('blog', {'active':1, 'id':blog_id})
+			b = req.store.load_one('blog', active=1, url_code=req.postpath[0])
+		else:
+			b = req.store.load_one('blog', active=1, id=blog_id)
+			if(b):
+				app.redirect(req.get_path('blog', b.url_code), permanent=True)
 		
 		if(b is None):
-			app.raise404(blog_id)
+			app.raise404(req.postpath[0])
 		
 		self.set_slot('title', b.title)
 		self.set_slot('blog', b)
